SplitTxRx

Trait SplitTxRx 

pub trait SplitTxRx {
    type Tx;
    type Rx;

    // Required method
    fn split(self) -> (Self::Tx, Self::Rx);
}
Split a CAN interface into transmit and receive halves.

This trait is usually implemented for a concrete CAN driver type that internally owns shared state, returning lightweight wrapper types (Tx, Rx) that can be borrowed independently.

Required Associated Types

type Tx

Transmit half type.

This typically implements TxFrameIo and/or AsyncTxFrameIo.

type Rx

Receive half type.

This typically implements RxFrameIo and/or AsyncRxFrameIo.

Required Methods

fn split(self) -> (Self::Tx, Self::Rx)

Split into (Tx, Rx) halves.

Implementors